@@ -28,11 +28,7 @@ from itertools import product
 
 from inspire_utils.record import get_value
 
-from .utils import (
-    compute_author_match_score,
-    compute_jaccard_index,
-    get_tokenized_title,
-)
+from inspire_matcher.utils import compute_author_match_score, compute_title_score
 
 
 def default_validator(record, result):
@@ -42,37 +38,39 @@ def default_validator(record, result):
 def authors_titles_validator(record, result):
     """Compute a validation score for the possible match.
 
-    The score is based on a similarity score of the authors sets and the maximum Jaccard index found between 2 titles:
+    The score is based on a similarity score of the authors sets and
+        the maximum Jaccard index found between 2 titles:
     one from the record and one from the result title sets.
 
-    If the computed score is higher than 0.5, then the match is valid, otherwise it is not.
+    If the computed score is higher than 0.5, then the match is valid,
+    otherwise it is not.
 
     Args:
-        record (dict): the given record we are trying to match with similar ones in INSPIRE.
-        result (dict): possible match returned by the ES query that needs to be validated.
+        record (dict): the given record we are trying to match
+            with similar ones in INSPIRE.
+        result (dict): possible match returned by the ES query
+            that needs to be validated.
 
     Returns:
         bool: validation decision.
 
     """
-    record_authors = get_value(record, 'authors', [])
-    result_authors = get_value(result, '_source.authors', [])
+    record_authors = get_value(record, "authors", [])
+    result_authors = get_value(result, "_source.authors", [])
 
     author_score = compute_author_match_score(record_authors, result_authors)
 
-    title_max_score = 0.0
-    record_titles = get_value(record, 'titles.title', [])
-    result_titles = get_value(result, '_source.titles.title', [])
+    record_titles = get_value(record, "titles.title", [])
+    result_titles = get_value(result, "_source.titles.title", [])
 
-    for cartesian_pair in product(record_titles, result_titles):
-        record_title_tokens = get_tokenized_title(cartesian_pair[0])
-        result_title_tokens = get_tokenized_title(cartesian_pair[1])
-        current_title_jaccard = compute_jaccard_index(record_title_tokens, result_title_tokens)
+    title_score = max(
+        compute_title_score(
+            record_title, result_title, threshold=0.5, math_threshold=0.3
+        )
+        for (record_title, result_title) in product(record_titles, result_titles)
+    )
 
-        if current_title_jaccard > title_max_score and current_title_jaccard >= 0.5:
-            title_max_score = current_title_jaccard
-
-    return (author_score + title_max_score) / 2 > 0.5
+    return (author_score + title_score) / 2 > 0.5
 
 
 def cds_identifier_validator(record, result):
@@ -84,19 +82,31 @@ def cds_identifier_validator(record, result):
     ``schema`` different from CDS.
 
     Args:
-        record (dict): the given record we are trying to match with similar ones in INSPIRE.
-        result (dict): possible match returned by the ES query that needs to be validated.
+        record (dict): the given record we are trying to match with
+            similar ones in INSPIRE.
+        result (dict): possible match returned by the ES query
+            that needs to be validated.
 
     Returns:
         bool: validation decision.
 
     """
 
-    record_external_identifiers = get_value(record, 'external_system_identifiers', [])
-    result_external_identifiers = get_value(result, '_source.external_system_identifiers', [])
+    record_external_identifiers = get_value(record, "external_system_identifiers", [])
+    result_external_identifiers = get_value(
+        result, "_source.external_system_identifiers", []
+    )
 
-    record_external_identifiers = {external_id["value"] for external_id in record_external_identifiers if external_id["schema"] == 'CDS'}
-    result_external_identifiers = {external_id["value"] for external_id in result_external_identifiers if external_id["schema"] == 'CDS'}
+    record_external_identifiers = {
+        external_id["value"]
+        for external_id in record_external_identifiers
+        if external_id["schema"] == "CDS"
+    }
+    result_external_identifiers = {
+        external_id["value"]
+        for external_id in result_external_identifiers
+        if external_id["schema"] == "CDS"
+    }
 
     return bool(record_external_identifiers & result_external_identifiers)
 
@@ -109,3 +119,11 @@ def persistent_identifier_validator(record, result):
     result_pid_values = {frozenset(pid.values()) for pid in result_pids}
 
     return bool(record_pid_values & result_pid_values)
+
+
+def arxiv_eprints_validator(record, result):
+    record_eprints = set(get_value(record, "arxiv_eprints.value", []))
+    result_eprints = set(get_value(result, "_source.arxiv_eprints.value", []))
+    if not record_eprints or not result_eprints:
+        return True
+    return bool(record_eprints & result_eprints)
